@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -56,7 +56,7 @@ ThemeEditorPage::ThemeEditorPage(const QString &projectDir, const QString &theme
     mTabWidget->addTab(mEditorPage, i18n("Editor (%1)", QStringLiteral("theme.html")));
 
     GrantleeThemeEditor::DesktopFilePage::DesktopFileOptions opt;
-    mDesktopPage = new GrantleeThemeEditor::DesktopFilePage(QStringLiteral("theme.html"), opt);
+    mDesktopPage = new GrantleeThemeEditor::DesktopFilePage(QStringLiteral("theme.html"), opt, this);
     mDesktopPage->setDefaultDesktopName(QStringLiteral("theme.desktop"));
     mDesktopPage->setThemeName(themeName);
     mTabWidget->addTab(mDesktopPage, i18n("Desktop File"));
@@ -212,7 +212,7 @@ void ThemeEditorPage::addExtraPage()
 {
     QString filename = QInputDialog::getText(this, i18n("Filename of extra page"), i18n("Filename:"));
     if (!filename.trimmed().isEmpty()) {
-        if (!filename.endsWith(QStringLiteral(".html")) && !filename.endsWith(QStringLiteral(".css")) && !filename.endsWith(QStringLiteral(".js"))) {
+        if (!filename.endsWith(QLatin1String(".html")) && !filename.endsWith(QLatin1String(".css")) && !filename.endsWith(QLatin1String(".js"))) {
             filename += QLatin1String(".html");
         }
         createExtraPage(filename);
